@@ -75,7 +75,7 @@ const gchar *general_tags[] = {
 
 const gchar *interface_tags[] = {
   "address", "auto", "bootproto", "broadcast", "debug", "dial_command",
-  "external_line", "file", "netmask", "network", "noauth", "persist",
+  "essid", "external_line", "file", "key", "netmask", "network", "noauth", "persist",
   "phone_number", "section", "serial_hwctl", "serial_port", "set_default_gw",
   "update_dns", "volume", "user", NULL
 };
@@ -350,6 +350,7 @@ delete_location (GstLocation *location)
   GtkTreeIter   iter;
   GtkWidget    *dialog;
   gint          response;
+  xmlNodePtr    profile;
 
   priv  = GST_LOCATION_GET_PRIVATE (location);
   model = gtk_combo_box_get_model (GTK_COMBO_BOX (location));
@@ -366,6 +367,13 @@ delete_location (GstLocation *location)
 
   if (response == GTK_RESPONSE_YES)
     {
+      gtk_tree_model_get (model, &iter,
+			  LOCATION_COL_DATA, &profile,
+			  -1);
+
+      if (profile)
+	gst_xml_element_destroy (profile);
+
       gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
       gtk_combo_box_set_active (GTK_COMBO_BOX (location), -1);
       gst_dialog_modify (tool->main_dialog);
@@ -687,7 +695,7 @@ compare_current_with_profile (xmlNodePtr current, xmlNodePtr profile)
 static void
 copy_tag_list (xmlNodePtr source, xmlNodePtr dest, const gchar *list[])
 {
-  gchar **string = (gchar **) list;;
+  gchar **string = (gchar **) list;
   gchar  *value;
 
   while (*string)
